@@ -127,7 +127,17 @@ class TestEmit(unittest.TestCase):
         e.register("test_stop", self.on_echo)
         await e.start()
         await e.stop()
+        for binding in e._registry.values():
+            self.assertFalse(binding['queue'])
+            self.assertFalse(binding['handlers'])
+        e.register("test_stop", self.on_echo)
 
+        await e.start()
+        await e.stop()
+        for binding in e._registry.values():
+            self.assertFalse(binding['queue'])
+            self.assertFalse(binding['handlers'])
+            
     @async_test
     async def test_redis_stop(self):
         e.register("test_stop", self.on_echo)
